@@ -1,6 +1,6 @@
 #![allow(dead_code, non_snake_case, non_camel_case_types, non_upper_case_globals)]
 pub type MustUseInt = ::std::os::raw::c_int;
-extern "C" {
+unsafe extern "C" {
     #[must_use]
     pub fn return_int() -> MustUseInt;
 }
@@ -10,17 +10,17 @@ extern "C" {
 pub struct MustUseStruct {
     _unused: [u8; 0],
 }
-extern "C" {
+unsafe extern "C" {
     #[must_use]
     pub fn return_struct() -> MustUseStruct;
 }
 /// <div rustbindgen mustusetype></div>
 pub type AnnotatedInt = ::std::os::raw::c_int;
-extern "C" {
+unsafe extern "C" {
     #[must_use]
     pub fn return_annotated_int() -> AnnotatedInt;
 }
-extern "C" {
+unsafe extern "C" {
     pub fn return_plain_int() -> ::std::os::raw::c_int;
 }
 /// <div rustbindgen mustusetype></div>
@@ -33,7 +33,7 @@ const _: () = {
     ["Size of AnnotatedStruct"][::std::mem::size_of::<AnnotatedStruct>() - 0usize];
     ["Alignment of AnnotatedStruct"][::std::mem::align_of::<AnnotatedStruct>() - 1usize];
 };
-extern "C" {
+unsafe extern "C" {
     #[must_use]
     pub fn return_annotated_struct() -> AnnotatedStruct;
 }
@@ -47,10 +47,10 @@ const _: () = {
 };
 /// <div rustbindgen mustusetype></div>
 pub type TypedefPlainStruct = PlainStruct;
-extern "C" {
+unsafe extern "C" {
     pub fn return_plain_struct() -> PlainStruct;
 }
-extern "C" {
+unsafe extern "C" {
     #[must_use]
     pub fn return_typedef_struct() -> TypedefPlainStruct;
 }
